@@ -280,29 +280,6 @@ class BrailleGenerator(generator.Generator):
         result.reverse()
         return result
 
-    def _generateFocusedItem(self, obj, **args):
-        result = []
-        role = args.get('role', obj.getRole())
-        if role != pyatspi.ROLE_LIST:
-            return result
-
-        try:
-            s = obj.querySelection()
-        except NotImplementedError:
-            isFocused = \
-                lambda x: x and x.getState().contains(pyatspi.STATE_FOCUSED)
-            items = pyatspi.utils.findAllDescendants(obj, isFocused)
-        else:
-            items = [s.getSelectedChild(i) for i in range(s.nSelectedChildren)]
-            if not items and obj.childCount:
-                items.append(obj[0])
-
-        items = list(map(self._generateName, items))
-        for item in items:
-            result.extend(item)
-
-        return result
-
     #####################################################################
     #                                                                   #
     # Unfortunate hacks.                                                #
@@ -410,7 +387,7 @@ class BrailleGenerator(generator.Generator):
     def asString(self, content, delimiter=" "):
         combined = ""
         prior = None
-        if isinstance(content, basestring):
+        if isinstance(content, str):
             combined = content
         elif content and isinstance(content, list):
             # Strip off leading and trailing spaces.
@@ -420,11 +397,6 @@ class BrailleGenerator(generator.Generator):
             while content and isinstance(content[-1], Space):
                 content = content[0:-1]
             for element in content:
-                try:
-                    element = element.decode("UTF-8")
-                except UnicodeEncodeError:
-                    pass
-
                 if isinstance(element, Space) and prior:
                     combined += element.delimiter
                     prior = None
